@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2013  Zarafa B.V.
+ * Copyright 2005 - 2014  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -304,6 +304,10 @@
 #define PR_EXCEPTION_ENDTIME PROP_TAG(PT_SYSTIME, 0x7FFC)
 #endif
 
+#ifndef PR_EXCEPTION_REPLACETIME
+#define PR_EXCEPTION_REPLACETIME PROP_TAG(PT_SYSTIME, 0x7FF9)
+#endif
+
 #ifndef PR_ATTACHMENT_FLAGS
 #define PR_ATTACHMENT_FLAGS PROP_TAG(PT_LONG, 0x7FFD)
 #endif
@@ -825,4 +829,7 @@ PR_ADDITIONAL_REN_ENTRYIDS:
 #define RSF_ELID_ENTRYID			0x0001
 #define ELEMENT_SENTINEL			0x0000
 
+#define PR_PROFILE_MDB_DN			PROP_TAG(PT_STRING8, 0x7CFF)
+#define PR_FORCE_USE_ENTRYID_SERVER PROP_TAG(PT_BOOLEAN, 0x7CFE)
+
 #endif
